@@ -271,7 +271,7 @@ class SecurityContext(object):
             # set subaccount_id to the zone_id as a workaround, if subaccount id is not available.
             if 'subaccountid' in ext_attr and ext_attr.get('subaccountid'):
                 self._properties['subaccount_id'] = ext_attr.get('subaccountid')
-                self._logger.debug('Obtained subaccountid: %s.', self._properties['subaccountid'])
+                self._logger.debug('Obtained subaccountid: %s.', self._properties['subaccount_id'])
             else:
                 self._properties['subaccount_id'] = jwt_payload['zid']
                 self._logger.debug('Subaccountid not found. Using zid instead: %s.', jwt_payload['zid'])
